==> amps-c++-client-5.3.3.3-Linux.tar.gz: amps-c++-client-5.3.3.3-Linux/doc/html/search/functions_c.js <==
var searchData=
[
  ['newacktype',['newAckType',['../classAMPS_1_1Message.html#adbcf27a49b7a73bca7ee4cb96d1a20b1',1,'AMPS::Message']]],
  ['newbatchsize',['newBatchSize',['../classAMPS_1_1Message.html#a7ac12f03fc6a563308cfc062fd93da00',1,'AMPS::Message']]],
  ['newbookmark',['newBookmark',['../classAMPS_1_1Message.html#a72d5321eddeef8035efebe11c1acd05f',1,'AMPS::Message']]],
  ['newclientname',['newClientName',['../classAMPS_1_1Message.html#a319467276d1aaa3e413a0016eee6a78a',1,'AMPS::Message']]],
  ['newcommand',['newCommand',['../classAMPS_1_1Message.html#a950c51edf46b1d336ba9c02dc81dafe2',1,'AMPS::Message']]],
  ['newcommandid',['newCommandId',['../classAMPS_1_1Message.html#a375c97392882ea1eb606bdd4432ea98c',1,'AMPS::Message']]],
  ['newcorrelationid',['newCorrelationId',['../classAMPS_1_1Message.html#a4eb8941093d0871fea2625ceeae083f2',1,'AMPS::Message']]],
  ['newexpiration',['newExpiration',['../classAMPS_1_1Message.html#a1dc100971d371c00c688f543b4011dcd',1,'AMPS::Message']]],
  ['newfilter',['newFilter',['../classAMPS_1_1Message.html#a14e93b477cbf1b7c8ed38ccd0b4f7af5',1,'AMPS::Message']]],
  ['newgroupsequencenumber',['newGroupSequenceNumber',['../classAMPS_1_1Message.html#a59884fff50233a1a796b4e0334d54627',1,'AMPS::Message']]],
  ['newheartbeat',['newHeartbeat',['../classAMPS_1_1Message.html#af6d923258c024eb0419fabae74fd1618',1,'AMPS::Message']]],
  ['newleaseperiod',['newLeasePeriod',['../classAMPS_1_1Message.html#a28528511f549cb9f31eb29b13837d1c1',1,'AMPS::Message']]],
  ['newmatches',['newMatches',['../classAMPS_1_1Message.html#a20da6903386b5d3024256f4c66bd8022',1,'AMPS::Message']]],
  ['newmessagelength',['newMessageLength',['../classAMPS_1_1Message.html#a0b24fad29d5c2f1ca156ddebdae3c48b',1,'AMPS::Message']]],
  ['newmessagetype',['newMessageType',['../classAMPS_1_1Message.html#a519fc3cd742c6cc476d6185ddbaacedb',1,'AMPS::Message']]],
  ['neworderby',['newOrderBy',['../classAMPS_1_1Message.html#a923c1f6b3d063b4d7afc9cb577d747bd',1,'AMPS::Message']]],
  ['newpassword',['newPassword',['../classAMPS_1_1Message.html#a23fbed7de4e75d80e797f8c5caf93ba8',1,'AMPS::Message']]],
  ['newqueryid',['newQueryId',['../classAMPS_1_1Message.html#af0abc1c791ec6cbc73e6a4e97b32a18c',1,'AMPS::Message::newQueryId()'],['../classAMPS_1_1Message.html#a7c123a023af33c2c082f767020e38fe4',1,'AMPS::Message::newQueryID()']]],
  ['newreason',['newReason',['../classAMPS_1_1Message.html#a4eb236231460162573887ffd4a0ce87d',1,'AMPS::Message']]],
  ['newrecordsinserted',['newRecordsInserted',['../classAMPS_1_1Message.html#a64ea6c69dbf9e758f65895bcec49fa42',1,'AMPS::Message']]],
  ['newrecordsreturned',['newRecordsReturned',['../classAMPS_1_1Message.html#a3d2149e2a466ddcb71af713b10054bc4',1,'AMPS::Message']]],
  ['newrecordsupdated',['newRecordsUpdated',['../classAMPS_1_1Message.html#ae05544c2cdc10facb9dd7bd917682e36',1,'AMPS::Message']]],
  ['newsequence',['newSequence',['../classAMPS_1_1Message.html#aa54a28a4286232f57d922ae5b44fd274',1,'AMPS::Message']]],
  ['newsowdelete',['newSowDelete',['../classAMPS_1_1Message.html#ad27a2e54545642262f3fc1225b3c280c',1,'AMPS::Message']]],
  ['newsowkey',['newSowKey',['../classAMPS_1_1Message.html#a6390c52c5d67731dbb2899132cb3066b',1,'AMPS::Message']]],
  ['newsowkeys',['newSowKeys',['../classAMPS_1_1Message.html#ac9a330bcdfc96366fec6f263504f5c16',1,'AMPS::Message']]],
  ['newstatus',['newStatus',['../classAMPS_1_1Message.html#a696339eca6ade2fa4ef0ae0a2e0b4596',1,'AMPS::Message']]],
  ['newsubid',['newSubId',['../classAMPS_1_1Message.html#aaefb349df6192f2a280391e2e0c11820',1,'AMPS::Message']]],
  ['newsubscriptionid',['newSubscriptionId',['../classAMPS_1_1Message.html#aec194ba2e8f82520d0d8399bf91e404f',1,'AMPS::Message']]],
  ['newsubscriptionids',['newSubscriptionIds',['../classAMPS_1_1Message.html#ac3a367d5ff764e853c0ddbe810fb1cc6',1,'AMPS::Message']]],
  ['newtimeoutinterval',['newTimeoutInterval',['../classAMPS_1_1Message.html#a623834b099c1018be8547ed0d7bb84d4',1,'AMPS::Message']]],
  ['newtimestamp',['newTimestamp',['../classAMPS_1_1Message.html#a2373918b9758221ec8b09127a527fe59',1,'AMPS::Message']]],
  ['newtopic',['newTopic',['../classAMPS_1_1Message.html#ad7189a7083ae9853905cc60a32ea6971',1,'AMPS::Message']]],
  ['newtopicmatches',['newTopicMatches',['../classAMPS_1_1Message.html#acf595c213dd5baa1f776fde79bf220d3',1,'AMPS::Message']]],
  ['newtopnrecordsreturned',['newTopNRecordsReturned',['../classAMPS_1_1Message.html#a86e60c0a6b1cbca85b752882ac270449',1,'AMPS::Message']]],
  ['newuserid',['newUserId',['../classAMPS_1_1Message.html#a6753594041d78a829c3967c74f491c19',1,'AMPS::Message']]],
  ['newversion',['newVersion',['../classAMPS_1_1Message.html#adc4daf48185e63d53281244631555a08',1,'AMPS::Message']]],
  ['next',['next',['../classAMPS_1_1DefaultServerChooser.html#a1d1053afd168e884822e8da6de26325b',1,'AMPS::DefaultServerChooser::next()'],['../classAMPS_1_1RecoveryPointAdapterImpl.html#a78f6795a6d83b517677a067cc5a804cd',1,'AMPS::RecoveryPointAdapterImpl::next()'],['../classAMPS_1_1ConflatingRecoveryPointAdapter.html#a2cffcf175cf447ef6739edf7f30d0c4d',1,'AMPS::ConflatingRecoveryPointAdapter::next()'],['../classAMPS_1_1SOWRecoveryPointAdapter.html#a2670f64fd2f8135030e1b184efab8a3b',1,'AMPS::SOWRecoveryPointAdapter::next()']]],
  ['now',['NOW',['../classAMPS_1_1Client.html#a45f7323a20d0ca48db4386c4ee80d50f',1,'AMPS::Client']]]
];

==> amps-c++-client-5.3.4.5-Linux.tar.gz: amps-c++-client-5.3.4.5-Linux/doc/html/search/functions_c.js <==
var searchData=
[
  ['newacktype',['newAckType',['../classAMPS_1_1Message.html#adbcf27a49b7a73bca7ee4cb96d1a20b1',1,'AMPS::Message']]],
  ['newbatchsize',['newBatchSize',['../classAMPS_1_1Message.html#a7ac12f03fc6a563308cfc062fd93da00',1,'AMPS::Message']]],
  ['newbookmark',['newBookmark',['../classAMPS_1_1Message.html#a72d5321eddeef8035efebe11c1acd05f',1,'AMPS::Message']]],
  ['newclientname',['newClientName',['../classAMPS_1_1Message.html#a319467276d1aaa3e413a0016eee6a78a',1,'AMPS::Message']]],
  ['newcommand',['newCommand',['../classAMPS_1_1Message.html#a950c51edf46b1d336ba9c02dc81dafe2',1,'AMPS::Message']]],
  ['newcommandid',['newCommandId',['../classAMPS_1_1Message.html#a375c97392882ea1eb606bdd4432ea98c',1,'AMPS::Message']]],
  ['newcorrelationid',['newCorrelationId',['../classAMPS_1_1Message.html#a4eb8941093d0871fea2625ceeae083f2',1,'AMPS::Message']]],
  ['newexpiration',['newExpiration',['../classAMPS_1_1Message.html#a1dc100971d371c00c688f543b4011dcd',1,'AMPS::Message']]],
  ['newfilter',['newFilter',['../classAMPS_1_1Message.html#a14e93b477cbf1b7c8ed38ccd0b4f7af5',1,'AMPS::Message']]],
  ['newgroupsequencenumber',['newGroupSequenceNumber',['../classAMPS_1_1Message.html#a59884fff50233a1a796b4e0334d54627',1,'AMPS::Message']]],
  ['newheartbeat',['newHeartbeat',['../classAMPS_1_1Message.html#af6d923258c024eb0419fabae74fd1618',1,'AMPS::Message']]],
  ['newleaseperiod',['newLeasePeriod',['../classAMPS_1_1Message.html#a28528511f549cb9f31eb29b13837d1c1',1,'AMPS::Message']]],
  ['newmatches',['newMatches',['../classAMPS_1_1Message.html#a20da6903386b5d3024256f4c66bd8022',1,'AMPS::Message']]],
  ['newmessagelength',['newMessageLength',['../classAMPS_1_1Message.html#a0b24fad29d5c2f1ca156ddebdae3c48b',1,'AMPS::Message']]],
  ['newmessagetype',['newMessageType',['../classAMPS_1_1Message.html#a519fc3cd742c6cc476d6185ddbaacedb',1,'AMPS::Message']]],
  ['neworderby',['newOrderBy',['../classAMPS_1_1Message.html#a923c1f6b3d063b4d7afc9cb577d747bd',1,'AMPS::Message']]],
  ['newpassword',['newPassword',['../classAMPS_1_1Message.html#a23fbed7de4e75d80e797f8c5caf93ba8',1,'AMPS::Message']]],
  ['newqueryid',['newQueryID',['../classAMPS_1_1Message.html#a7c123a023af33c2c082f767020e38fe4',1,'AMPS::Message::newQueryID()'],['../classAMPS_1_1Message.html#af0abc1c791ec6cbc73e6a4e97b32a18c',1,'AMPS::Message::newQueryId()']]],
  ['newreason',['newReason',['../classAMPS_1_1Message.html#a4eb236231460162573887ffd4a0ce87d',1,'AMPS::Message']]],
  ['newrecordsinserted',['newRecordsInserted',['../classAMPS_1_1Message.html#a64ea6c69dbf9e758f65895bcec49fa42',1,'AMPS::Message']]],
  ['newrecordsreturned',['newRecordsReturned',['../classAMPS_1_1Message.html#a3d2149e2a466ddcb71af713b10054bc4',1,'AMPS::Message']]],
  ['newrecordsupdated',['newRecordsUpdated',['../classAMPS_1_1Message.html#ae05544c2cdc10facb9dd7bd917682e36',1,'AMPS::Message']]],
  ['newsequence',['newSequence',['../classAMPS_1_1Message.html#aa54a28a4286232f57d922ae5b44fd274',1,'AMPS::Message']]],
  ['newsowdelete',['newSowDelete',['../classAMPS_1_1Message.html#ad27a2e54545642262f3fc1225b3c280c',1,'AMPS::Message']]],
  ['newsowkey',['newSowKey',['../classAMPS_1_1Message.html#a6390c52c5d67731dbb2899132cb3066b',1,'AMPS::Message']]],
  ['newsowkeys',['newSowKeys',['../classAMPS_1_1Message.html#ac9a330bcdfc96366fec6f263504f5c16',1,'AMPS::Message']]],
  ['newstatus',['newStatus',['../classAMPS_1_1Message.html#a696339eca6ade2fa4ef0ae0a2e0b4596',1,'AMPS::Message']]],
  ['newsubid',['newSubId',['../classAMPS_1_1Message.html#aaefb349df6192f2a280391e2e0c11820',1,'AMPS::Message']]],
  ['newsubscriptionid',['newSubscriptionId',['../classAMPS_1_1Message.html#aec194ba2e8f82520d0d8399bf91e404f',1,'AMPS::Message']]],
  ['newsubscriptionids',['newSubscriptionIds',['../classAMPS_1_1Message.html#ac3a367d5ff764e853c0ddbe810fb1cc6',1,'AMPS::Message']]],
  ['newtimeoutinterval',['newTimeoutInterval',['../classAMPS_1_1Message.html#a623834b099c1018be8547ed0d7bb84d4',1,'AMPS::Message']]],
  ['newtimestamp',['newTimestamp',['../classAMPS_1_1Message.html#a2373918b9758221ec8b09127a527fe59',1,'AMPS::Message']]],
  ['newtopic',['newTopic',['../classAMPS_1_1Message.html#ad7189a7083ae9853905cc60a32ea6971',1,'AMPS::Message']]],
  ['newtopicmatches',['newTopicMatches',['../classAMPS_1_1Message.html#acf595c213dd5baa1f776fde79bf220d3',1,'AMPS::Message']]],
  ['newtopnrecordsreturned',['newTopNRecordsReturned',['../classAMPS_1_1Message.html#a86e60c0a6b1cbca85b752882ac270449',1,'AMPS::Message']]],
  ['newuserid',['newUserId',['../classAMPS_1_1Message.html#a6753594041d78a829c3967c74f491c19',1,'AMPS::Message']]],
  ['newversion',['newVersion',['../classAMPS_1_1Message.html#adc4daf48185e63d53281244631555a08',1,'AMPS::Message']]],
  ['next',['next',['../classAMPS_1_1DefaultServerChooser.html#a1d1053afd168e884822e8da6de26325b',1,'AMPS::DefaultServerChooser::next()'],['../classAMPS_1_1RecoveryPointAdapterImpl.html#a78f6795a6d83b517677a067cc5a804cd',1,'AMPS::RecoveryPointAdapterImpl::next()'],['../classAMPS_1_1ConflatingRecoveryPointAdapter.html#a2cffcf175cf447ef6739edf7f30d0c4d',1,'AMPS::ConflatingRecoveryPointAdapter::next()'],['../classAMPS_1_1SOWRecoveryPointAdapter.html#a2670f64fd2f8135030e1b184efab8a3b',1,'AMPS::SOWRecoveryPointAdapter::next()']]],
  ['now',['NOW',['../classAMPS_1_1Client.html#a45f7323a20d0ca48db4386c4ee80d50f',1,'AMPS::Client']]]
];
